@@ -15,7 +15,7 @@
 
 
 from sahara.api import acl
-from sahara.service import api
+from sahara.service.api.v2 import node_group_templates as api
 from sahara.service import validation as v
 from sahara.service.validations import node_group_template_schema as ngt_schema
 from sahara.service.validations import node_group_templates as v_ngt
@@ -27,18 +27,23 @@ rest = u.RestV2('node-group-templates', __name__)
 
 @rest.get('/node-group-templates')
 @acl.enforce("data-processing:node-group-templates:get_all")
+@v.check_exists(api.get_node_group_template, 'marker')
+@v.validate(None, v.validate_pagination_limit,
+            v.validate_sorting_node_group_templates)
 def node_group_templates_list():
-    return u.render(
-        node_group_templates=[t.to_dict()
-                              for t in api.get_node_group_templates(
-                              **u.get_request_args().to_dict())])
+    result = api.get_node_group_templates(**u.get_request_args().to_dict())
+    return u.render(res=result, name="node_group_templates")
 
 
 @rest.post('/node-group-templates')
 @acl.enforce("data-processing:node-group-templates:create")
-@v.validate(ngt_schema.NODE_GROUP_TEMPLATE_SCHEMA,
+@v.validate(ngt_schema.NODE_GROUP_TEMPLATE_SCHEMA_V2,
             v_ngt.check_node_group_template_create)
 def node_group_templates_create(data):
+    # renaming hadoop_version -> plugin_version
+    # this can be removed once APIv1 is deprecated
+    data['hadoop_version'] = data['plugin_version']
+    del data['plugin_version']
     return u.render(api.create_node_group_template(data).to_wrapped_dict())
 
 
@@ -50,12 +55,14 @@ def node_group_templates_get(node_group_template_id):
         api.get_node_group_template, node_group_template_id)
 
 
-@rest.put('/node-group-templates/<node_group_template_id>')
+@rest.patch('/node-group-templates/<node_group_template_id>')
 @acl.enforce("data-processing:node-group-templates:modify")
 @v.check_exists(api.get_node_group_template, 'node_group_template_id')
-@v.validate(ngt_schema.NODE_GROUP_TEMPLATE_UPDATE_SCHEMA,
+@v.validate(ngt_schema.NODE_GROUP_TEMPLATE_UPDATE_SCHEMA_V2,
             v_ngt.check_node_group_template_update)
 def node_group_templates_update(node_group_template_id, data):
+    data['hadoop_version'] = data['plugin_version']
+    del data['plugin_version']
     return u.to_wrapped_dict(
         api.update_node_group_template, node_group_template_id, data)
 
